@@ -110,9 +110,9 @@ impl Command for ExprOtherwise {
 #[cfg(test)]
 mod test {
     use super::super::super::test_dataframe::test_dataframe;
-    use crate::dataframe::eager::WithColumn;
+    use crate::dataframe::eager::{ToNu, WithColumn};
     use crate::dataframe::expressions::when::ExprWhen;
-    use crate::dataframe::expressions::{ExprAlias, ExprAsNu, ExprCol};
+    use crate::dataframe::expressions::{ExprAlias, ExprCol};
 
     use super::*;
 
@@ -124,7 +124,7 @@ mod test {
             Box::new(ExprAlias {}),
             Box::new(ExprWhen {}),
             Box::new(ExprOtherwise {}),
-            Box::new(ExprAsNu {}),
+            Box::new(ToNu {}),
         ])
     }
 }
