@@ -34,6 +34,11 @@ impl Command for Inspect {
     ) -> Result<PipelineData, ShellError> {
         let input_metadata = input.metadata();
         let input_val = input.into_value(call.head);
+        if input_val.is_nothing() {
+            return Err(ShellError::PipelineEmpty {
+                dst_span: call.head,
+            });
+        }
         let original_input = input_val.clone();
         let description = match input_val {
             Value::CustomValue { ref val, .. } => val.value_string(),
