@@ -26,7 +26,7 @@ impl Command for ConfigReset {
     }
 
     fn usage(&self) -> &str {
-        "Reset nushell environment configurations to default, and saves old config files in the config location as oldconfig.nu and oldenv.nu"
+        "Reset nushell environment configurations to default, and saves old config files in the config location as oldconfig.nu and oldenv.nu."
     }
 
     fn examples(&self) -> Vec<Example> {
