@@ -16,10 +16,7 @@ impl Command for Prepend {
 
     fn signature(&self) -> nu_protocol::Signature {
         Signature::build("prepend")
-            .input_output_types(vec![(
-                Type::List(Box::new(Type::Any)),
-                Type::List(Box::new(Type::Any)),
-            )])
+            .input_output_types(vec![(Type::Any, Type::List(Box::new(Type::Any)))])
             .required(
                 "row",
                 SyntaxShape::Any,
@@ -45,9 +42,30 @@ only unwrap the outer list, and leave the variable's contents untouched."#
 
     fn examples(&self) -> Vec<Example> {
         vec![
+            Example {
+                example: "0 | prepend [1 2 3]",
+                description: "prepend a list to an item",
+                result: Some(Value::List {
+                    vals: vec![
+                        Value::test_int(1),
+                        Value::test_int(2),
+                        Value::test_int(3),
+                        Value::test_int(0),
+                    ],
+                    span: Span::test_data(),
+                }),
+            },
+            Example {
+                example: r#""a" | prepend ["b"] "#,
+                description: "Prepend a list of strings to a string",
+                result: Some(Value::List {
+                    vals: vec![Value::test_string("b"), Value::test_string("a")],
+                    span: Span::test_data(),
+                }),
+            },
             Example {
                 example: "[1,2,3,4] | prepend 0",
-                description: "Prepend one Int item",
+                description: "Prepend one integer item",
                 result: Some(Value::List {
                     vals: vec![
                         Value::test_int(0),
@@ -61,7 +79,7 @@ only unwrap the outer list, and leave the variable's contents untouched."#
             },
             Example {
                 example: "[2,3,4] | prepend [0,1]",
-                description: "Prepend two Int items",
+                description: "Prepend two integer items",
                 result: Some(Value::List {
                     vals: vec![
                         Value::test_int(0),
@@ -75,7 +93,7 @@ only unwrap the outer list, and leave the variable's contents untouched."#
             },
             Example {
                 example: "[2,nu,4,shell] | prepend [0,1,rocks]",
-                description: "Prepend Ints and Strings",
+                description: "Prepend integers and strings",
                 result: Some(Value::List {
                     vals: vec![
                         Value::test_int(0),
