@@ -90,7 +90,7 @@ impl Command for TakeUntil {
         let redirect_stderr = call.redirect_stderr;
 
         Ok(input
-            .into_iter()
+            .into_iter_strict(span)?
             .take_while(move |value| {
                 if let Some(var_id) = var_id {
                     stack.add_var(var_id, value.clone());
