@@ -27,8 +27,7 @@ impl Command for Transpose {
     fn signature(&self) -> Signature {
         Signature::build("transpose")
             .input_output_types(vec![
-                (Type::Table(vec![]), Type::Table(vec![])),
-                (Type::Table(vec![]), Type::Record(vec![])),
+                (Type::Table(vec![]), Type::Any),
                 (Type::Record(vec![]), Type::Table(vec![])),
             ])
             .switch(
