@@ -15,7 +15,7 @@ impl Command for SubCommand {
     fn signature(&self) -> Signature {
         Signature::build("math max")
             .input_output_types(vec![
-                (Type::List(Box::new(Type::Number)), Type::Number),
+                (Type::List(Box::new(Type::Any)), Type::Any),
                 (Type::Table(vec![]), Type::Record(vec![])),
             ])
             .allow_variants_without_examples(true)
@@ -23,7 +23,7 @@ impl Command for SubCommand {
     }
 
     fn usage(&self) -> &str {
-        "Returns the maximum of a list of numbers, or of columns in a table."
+        "Returns the maximum of a list of values, or of columns in a table."
     }
 
     fn search_terms(&self) -> Vec<&str> {
