@@ -41,9 +41,9 @@ pub fn max(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellError
         } else {
             return Err(ShellError::OperatorMismatch {
                 op_span: head,
-                lhs_ty: biggest.get_type(),
+                lhs_ty: biggest.get_type().to_string(),
                 lhs_span: biggest.span()?,
-                rhs_ty: value.get_type(),
+                rhs_ty: value.get_type().to_string(),
                 rhs_span: value.span()?,
             });
         }
@@ -72,9 +72,9 @@ pub fn min(data: Vec<Value>, span: Span, head: Span) -> Result<Value, ShellError
         } else {
             return Err(ShellError::OperatorMismatch {
                 op_span: head,
-                lhs_ty: smallest.get_type(),
+                lhs_ty: smallest.get_type().to_string(),
                 lhs_span: smallest.span()?,
-                rhs_ty: value.get_type(),
+                rhs_ty: value.get_type().to_string(),
                 rhs_span: value.span()?,
             });
         }
