@@ -1,25 +1,20 @@
 use std::path::{Path, PathBuf};
 
-use nu_engine::{current_dir, CallExt};
+use nu_engine::current_dir;
 use nu_path::expand_path_with;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{EngineState, Stack};
 use nu_protocol::{
-    engine::Command, Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    engine::Command, Example, PipelineData, ShellError, Signature, Span, Type, Value,
 };
 
 use super::PathSubcommandArguments;
 
 struct Arguments {
-    columns: Option<Vec<String>>,
     pwd: PathBuf,
 }
 
-impl PathSubcommandArguments for Arguments {
-    fn get_columns(&self) -> Option<Vec<String>> {
-        self.columns.clone()
-    }
-}
+impl PathSubcommandArguments for Arguments {}
 
 #[derive(Clone)]
 pub struct SubCommand;
@@ -30,14 +25,13 @@ impl Command for SubCommand {
     }
 
     fn signature(&self) -> Signature {
-        Signature::build("path exists")
-            .input_output_types(vec![(Type::String, Type::Bool)])
-            .named(
-                "columns",
-                SyntaxShape::Table,
-                "For a record or table input, check strings at the given columns, and replace with result",
-                Some('c'),
-            )
+        Signature::build("path exists").input_output_types(vec![
+            (Type::String, Type::Bool),
+            (
+                Type::List(Box::new(Type::String)),
+                Type::List(Box::new(Type::Bool)),
+            ),
+        ])
     }
 
     fn usage(&self) -> &str {
@@ -58,7 +52,6 @@ If you need to distinguish dirs and files, please use `path type`."#
     ) -> Result<PipelineData, ShellError> {
         let head = call.head;
         let args = Arguments {
-            columns: call.get_flag(engine_state, stack, "columns")?,
             pwd: current_dir(engine_state, stack)?,
         };
         // This doesn't match explicit nulls
@@ -80,9 +73,12 @@ If you need to distinguish dirs and files, please use `path type`."#
                 result: Some(Value::test_bool(false)),
             },
             Example {
-                description: "Check if a file exists in a column",
-                example: "ls | path exists -c [ name ]",
-                result: None,
+                description: "Check if files in list exist",
+                example: r"[ C:\joe\todo.txt, C:\Users\doe\todo.txt ] | path exists",
+                result: Some(Value::test_list(vec![
+                    Value::test_bool(false),
+                    Value::test_bool(false),
+                ])),
             },
         ]
     }
@@ -96,9 +92,12 @@ If you need to distinguish dirs and files, please use `path type`."#
                 result: Some(Value::test_bool(false)),
             },
             Example {
-                description: "Check if a file exists in a column",
-                example: "ls | path exists -c [ name ]",
-                result: None,
+                description: "Check if files in list exist",
+                example: "[ /home/joe/todo.txt, /home/doe/todo.txt ] | path exists",
+                result: Some(Value::test_list(vec![
+                    Value::test_bool(false),
+                    Value::test_bool(false),
+                ])),
             },
         ]
     }
