@@ -41,8 +41,8 @@ impl Command for SubCommand {
                 (Type::String, Type::Int),
                 (Type::List(Box::new(Type::String)), Type::List(Box::new(Type::Int))),
                 (Type::Table(vec![]), Type::Table(vec![])),
+                (Type::Record(vec![]), Type::Record(vec![])),
             ])
-            .vectorizes_over_list(true) // TODO: no test coverage
             .allow_variants_without_examples(true)
             .required("string", SyntaxShape::String, "the string to find in the input")
             .switch(
