@@ -38,12 +38,12 @@ impl Command for SubCommand {
                 (Type::String, Type::String),
                 // TODO: clarify behavior with cellpath-rest argument
                 (Type::Table(vec![]), Type::Table(vec![])),
+                (Type::Record(vec![]), Type::Record(vec![])),
                 (
                     Type::List(Box::new(Type::String)),
                     Type::List(Box::new(Type::String)),
                 ),
             ])
-            .vectorizes_over_list(true)
             .required("find", SyntaxShape::String, "the pattern to find")
             .required("replace", SyntaxShape::String, "the replacement string")
             .rest(
@@ -135,6 +135,20 @@ impl Command for SubCommand {
                     span: Span::test_data(),
                 }),
             },
+            Example {
+                description: "Find and replace all occurrences of find string in record",
+                example:
+                    "{ KeyA: abc, KeyB: abc, KeyC: ads } | str replace -a 'b' 'z' KeyA KeyC",
+                result: Some(Value::Record {
+                        cols: vec!["KeyA".to_string(), "KeyB".to_string(), "KeyC".to_string()],
+                        vals: vec![
+                            Value::test_string("azc"),
+                            Value::test_string("abc"),
+                            Value::test_string("ads"),
+                        ],
+                        span: Span::test_data(),
+                    }),
+            },
             Example {
                 description: "Find and replace contents without using the replace parameter as a regular expression",
                 example: r"'dogs_$1_cats' | str replace '\$1' '$2' -n",
