@@ -1,4 +1,3 @@
-mod benchmark;
 mod complete;
 #[cfg(unix)]
 mod exec;
@@ -16,7 +15,6 @@ mod run_external;
 mod sys;
 mod which_;
 
-pub use benchmark::Benchmark;
 pub use complete::Complete;
 #[cfg(unix)]
 pub use exec::Exec;
