@@ -2,39 +2,27 @@ use nu_test_support::{nu, pipeline};
 
 #[test]
 fn base64_defaults_to_encoding_with_standard_character_type() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
         echo 'username:password' | encode base64
-        "#
-        )
-    );
+        "#);
 
     assert_eq!(actual.out, "dXNlcm5hbWU6cGFzc3dvcmQ=");
 }
 
 #[test]
 fn base64_encode_characterset_binhex() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
         echo 'username:password' | encode base64 --character-set binhex
-        "#
-        )
-    );
+        "#);
 
     assert_eq!(actual.out, "F@0NEPjJD97kE\'&bEhFZEP3");
 }
 
 #[test]
 fn error_when_invalid_character_set_given() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
         echo 'username:password' | encode base64 --character-set 'this is invalid'
-        "#
-        )
-    );
+        "#);
 
     assert!(actual
         .err
@@ -43,26 +31,18 @@ fn error_when_invalid_character_set_given() {
 
 #[test]
 fn base64_decode_characterset_binhex() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
         echo "F@0NEPjJD97kE'&bEhFZEP3" | decode base64 --character-set binhex --binary | decode utf-8
-        "#
-        )
-    );
+        "#);
 
     assert_eq!(actual.out, "username:password");
 }
 
 #[test]
 fn error_invalid_decode_value() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
         echo "this should not be a valid encoded value" | decode base64 --character-set url-safe
-        "#
-        )
-    );
+        "#);
 
     assert!(actual
         .err
