@@ -2,7 +2,7 @@ use nu_test_support::{nu, pipeline};
 
 #[test]
 fn regular_columns() {
-    let actual = nu!(cwd: ".", pipeline(
+    let actual = nu!(pipeline(
         r#"
             echo [
                 [first_name, last_name, rusty_at, type];
@@ -22,15 +22,14 @@ fn regular_columns() {
 
 #[test]
 fn skip_cell_rejection() {
-    let actual = nu!(cwd: ".", pipeline(
-        r#"[ {a: 1, b: 2,c:txt}, { a:val } ] | reject a | get c?.0"#));
+    let actual = nu!("[ {a: 1, b: 2,c:txt}, { a:val } ] | reject a | get c?.0");
 
     assert_eq!(actual.out, "txt");
 }
 
 #[test]
 fn complex_nested_columns() {
-    let actual = nu!(cwd: ".", pipeline(
+    let actual = nu!(pipeline(
         r#"
             {
                 "nu": {
@@ -63,7 +62,7 @@ fn complex_nested_columns() {
 
 #[test]
 fn ignores_duplicate_columns_rejected() {
-    let actual = nu!(cwd: ".", pipeline(
+    let actual = nu!(pipeline(
         r#"
             echo [
                 ["first name", "last name"];
@@ -82,60 +81,36 @@ fn ignores_duplicate_columns_rejected() {
 
 #[test]
 fn reject_record_from_raw_eval() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-            r#"
-            {"a": 3} | reject a | describe
-            "#
-        )
-    );
+    let actual = nu!(r#"{"a": 3} | reject a | describe"#);
 
     assert!(actual.out.contains("record"));
 }
 
 #[test]
 fn reject_table_from_raw_eval() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-            r#"
-            [{"a": 3}] | reject a
-            "#
-        )
-    );
+    let actual = nu!(r#"[{"a": 3}] | reject a"#);
 
     assert!(actual.out.contains("record 0 fields"));
 }
 
 #[test]
 fn reject_nested_field() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-            r#"
-            {a:{b:3,c:5}} | reject a.b | debug
-            "#
-        )
-    );
+    let actual = nu!("{a:{b:3,c:5}} | reject a.b | debug");
 
     assert_eq!(actual.out, "{a: {c: 5}}");
 }
 
 #[test]
 fn reject_two_identical_elements() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-            r#"[[a, a]; [1, 2]] | reject a"#
-        )
-    );
+    let actual = nu!("[[a, a]; [1, 2]] | reject a");
+
     assert!(actual.out.contains("record 0 fields"));
 }
 
 #[test]
 fn reject_large_vec_with_two_identical_elements() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-            r#"[[a, b, c, d, e, a]; [1323, 23, 45, 100, 2, 2423]] | reject a"#
-        )
-    );
+    let actual = nu!("[[a, b, c, d, e, a]; [1323, 23, 45, 100, 2, 2423]] | reject a");
+
     assert!(!actual.out.contains("1323"));
     assert!(!actual.out.contains("2423"));
     assert!(actual.out.contains('b'));
