@@ -17,7 +17,7 @@ fn binary_skip() {
 
 #[test]
 fn fail_on_non_iterator() {
-    let actual = nu!(cwd: ".", pipeline("1 | skip 2"));
+    let actual = nu!("1 | skip 2");
 
-    assert!(actual.err.contains("only_supports_this_input_type"));
+    assert!(actual.err.contains("command doesn't support"));
 }
