@@ -22,10 +22,7 @@ fn filters_with_nothing_comparison() {
 
 #[test]
 fn where_inside_block_works() {
-    let actual = nu!(
-        cwd: ".",
-        "{|x| ls | where $it =~ 'foo' } | describe"
-    );
+    let actual = nu!("{|x| ls | where $it =~ 'foo' } | describe");
 
     assert_eq!(actual.out, "closure");
 }
@@ -84,65 +81,65 @@ fn where_uses_enumerate_index() {
 fn binary_operator_comparisons() {
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get ints
             | first 4
             | where z > 4200
             | get z.0
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "4253");
 
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get ints
             | first 4
             | where z >= 4253
             | get z.0
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "4253");
 
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get ints
             | first 4
             | where z < 10
             | get z.0
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "1");
 
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get ints
             | first 4
             | where z <= 1
             | get z.0
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "1");
 
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get ints
             | where z != 1
             | first
             | get z
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "42");
@@ -153,24 +150,24 @@ fn binary_operator_comparisons() {
 fn contains_operator() {
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get strings
             | where x =~ ell
             | length
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "4");
 
     let actual = nu!(
         cwd: "tests/fixtures/formats", pipeline(
-        r#"
+        "
             open sample.db
             | get strings
             | where x !~ ell
             | length
-        "#
+        "
     ));
 
     assert_eq!(actual.out, "2");
@@ -178,9 +175,9 @@ fn contains_operator() {
 
 #[test]
 fn fail_on_non_iterator() {
-    let actual = nu!(cwd: ".", pipeline(r#"{"name": "foo", "size": 3} | where name == "foo""#));
+    let actual = nu!(r#"{"name": "foo", "size": 3} | where name == "foo""#);
 
-    assert!(actual.err.contains("only_supports_this_input_type"));
+    assert!(actual.err.contains("command doesn't support"));
 }
 
 // Test that filtering on columns that might be missing/null works
