@@ -121,7 +121,7 @@ pub fn eval_call(
                             } else if let Some(value) = &named.default_value {
                                 callee_stack.add_var(var_id, value.to_owned());
                             } else {
-                                callee_stack.add_var(var_id, Value::boolean(true, call.head))
+                                callee_stack.add_var(var_id, Value::bool(true, call.head))
                             }
                             found = true;
                         }
@@ -133,7 +133,7 @@ pub fn eval_call(
                         } else if let Some(value) = &named.default_value {
                             callee_stack.add_var(var_id, value.to_owned());
                         } else {
-                            callee_stack.add_var(var_id, Value::boolean(true, call.head))
+                            callee_stack.add_var(var_id, Value::bool(true, call.head))
                         }
                         found = true;
                     }
@@ -141,7 +141,7 @@ pub fn eval_call(
 
                 if !found {
                     if named.arg.is_none() {
-                        callee_stack.add_var(var_id, Value::boolean(false, call.head))
+                        callee_stack.add_var(var_id, Value::bool(false, call.head))
                     } else if let Some(value) = named.default_value {
                         callee_stack.add_var(var_id, value);
                     } else {
@@ -275,7 +275,7 @@ pub fn eval_expression(
     expr: &Expression,
 ) -> Result<Value, ShellError> {
     match &expr.expr {
-        Expr::Bool(b) => Ok(Value::boolean(*b, expr.span)),
+        Expr::Bool(b) => Ok(Value::bool(*b, expr.span)),
         Expr::Int(i) => Ok(Value::int(*i, expr.span)),
         Expr::Float(f) => Ok(Value::float(*f, expr.span)),
         Expr::Binary(b) => Ok(Value::Binary {
@@ -367,7 +367,7 @@ pub fn eval_expression(
         Expr::UnaryNot(expr) => {
             let lhs = eval_expression(engine_state, stack, expr)?;
             match lhs {
-                Value::Bool { val, .. } => Ok(Value::boolean(!val, expr.span)),
+                Value::Bool { val, .. } => Ok(Value::bool(!val, expr.span)),
                 _ => Err(ShellError::TypeMismatch {
                     err_message: "bool".to_string(),
                     span: expr.span,
@@ -384,7 +384,7 @@ pub fn eval_expression(
                     match boolean {
                         Boolean::And => {
                             if lhs.is_false() {
-                                Ok(Value::boolean(false, expr.span))
+                                Ok(Value::bool(false, expr.span))
                             } else {
                                 let rhs = eval_expression(engine_state, stack, rhs)?;
                                 lhs.and(op_span, &rhs, expr.span)
@@ -392,7 +392,7 @@ pub fn eval_expression(
                         }
                         Boolean::Or => {
                             if lhs.is_true() {
-                                Ok(Value::boolean(true, expr.span))
+                                Ok(Value::bool(true, expr.span))
                             } else {
                                 let rhs = eval_expression(engine_state, stack, rhs)?;
                                 lhs.or(op_span, &rhs, expr.span)
@@ -489,51 +489,63 @@ pub fn eval_expression(
                                 Err(ShellError::AssignmentRequiresMutableVar { lhs_span: lhs.span })
                             }
                         }
-                        Expr::FullCellPath(cell_path) => match &cell_path.head.expr {
-                            Expr::Var(var_id) | Expr::VarDecl(var_id) => {
-                                // The $env variable is considered "mutable" in Nushell.
-                                // As such, give it special treatment here.
-                                let is_env = var_id == &ENV_VARIABLE_ID;
-                                if is_env || engine_state.get_var(*var_id).mutable {
-                                    let mut lhs =
-                                        eval_expression(engine_state, stack, &cell_path.head)?;
+                        Expr::FullCellPath(cell_path) => {
+                            match &cell_path.head.expr {
+                                Expr::Var(var_id) | Expr::VarDecl(var_id) => {
+                                    // The $env variable is considered "mutable" in Nushell.
+                                    // As such, give it special treatment here.
+                                    let is_env = var_id == &ENV_VARIABLE_ID;
+                                    if is_env || engine_state.get_var(*var_id).mutable {
+                                        let mut lhs =
+                                            eval_expression(engine_state, stack, &cell_path.head)?;
 
-                                    lhs.upsert_data_at_cell_path(&cell_path.tail, rhs)?;
-                                    if is_env {
-                                        if cell_path.tail.is_empty() {
-                                            return Err(ShellError::CannotReplaceEnv {
-                                                span: cell_path.head.span,
-                                            });
-                                        }
+                                        lhs.upsert_data_at_cell_path(&cell_path.tail, rhs)?;
+                                        if is_env {
+                                            if cell_path.tail.is_empty() {
+                                                return Err(ShellError::CannotReplaceEnv {
+                                                    span: cell_path.head.span,
+                                                });
+                                            }
 
-                                        // The special $env treatment: for something like $env.config.history.max_size = 2000,
-                                        // get $env.config (or whichever one it is) AFTER the above mutation, and set it
-                                        // as the "config" environment variable.
-                                        let vardata = lhs.follow_cell_path(
-                                            &[cell_path.tail[0].clone()],
-                                            false,
-                                        )?;
-                                        match &cell_path.tail[0] {
-                                            PathMember::String { val, .. } => {
-                                                stack.add_env_var(val.to_string(), vardata);
-                                            }
-                                            // In case someone really wants an integer env-var
-                                            PathMember::Int { val, .. } => {
-                                                stack.add_env_var(val.to_string(), vardata);
+                                            // The special $env treatment: for something like $env.config.history.max_size = 2000,
+                                            // get $env.config (or whichever one it is) AFTER the above mutation, and set it
+                                            // as the "config" environment variable.
+                                            let vardata = lhs.follow_cell_path(
+                                                &[cell_path.tail[0].clone()],
+                                                false,
+                                            )?;
+                                            match &cell_path.tail[0] {
+                                                PathMember::String { val, span, .. } => {
+                                                    if val == "FILE_PWD"
+                                                        || val == "CURRENT_FILE"
+                                                        || val == "PWD"
+                                                    {
+                                                        return Err(ShellError::AutomaticEnvVarSetManually {
+                                                    envvar_name: val.to_string(),
+                                                    span: *span,
+                                                });
+                                                    } else {
+                                                        stack.add_env_var(val.to_string(), vardata);
+                                                    }
+                                                }
+                                                // In case someone really wants an integer env-var
+                                                PathMember::Int { val, .. } => {
+                                                    stack.add_env_var(val.to_string(), vardata);
+                                                }
                                             }
+                                        } else {
+                                            stack.add_var(*var_id, lhs);
                                         }
+                                        Ok(Value::nothing(cell_path.head.span))
                                     } else {
-                                        stack.add_var(*var_id, lhs);
+                                        Err(ShellError::AssignmentRequiresMutableVar {
+                                            lhs_span: lhs.span,
+                                        })
                                     }
-                                    Ok(Value::nothing(cell_path.head.span))
-                                } else {
-                                    Err(ShellError::AssignmentRequiresMutableVar {
-                                        lhs_span: lhs.span,
-                                    })
                                 }
+                                _ => Err(ShellError::AssignmentRequiresVar { lhs_span: lhs.span }),
                             }
-                            _ => Err(ShellError::AssignmentRequiresVar { lhs_span: lhs.span }),
-                        },
+                        }
                         _ => Err(ShellError::AssignmentRequiresVar { lhs_span: lhs.span }),
                     }
                 }
@@ -783,7 +795,10 @@ pub fn eval_element_with_input(
             redirect_stderr,
         ),
         PipelineElement::Redirection(span, redirection, expr) => match &expr.expr {
-            Expr::String(_) => {
+            Expr::String(_)
+            | Expr::FullCellPath(_)
+            | Expr::StringInterpolation(_)
+            | Expr::Filepath(_) => {
                 let exit_code = match &mut input {
                     PipelineData::ExternalStream { exit_code, .. } => exit_code.take(),
                     _ => None,
@@ -868,7 +883,16 @@ pub fn eval_element_with_input(
             out: (out_span, out_expr),
             err: (err_span, err_expr),
         } => match (&out_expr.expr, &err_expr.expr) {
-            (Expr::String(_), Expr::String(_)) => {
+            (
+                Expr::String(_)
+                | Expr::FullCellPath(_)
+                | Expr::StringInterpolation(_)
+                | Expr::Filepath(_),
+                Expr::String(_)
+                | Expr::FullCellPath(_)
+                | Expr::StringInterpolation(_)
+                | Expr::Filepath(_),
+            ) => {
                 if let Some(save_command) = engine_state.find_decl(b"save", &[]) {
                     let exit_code = match &mut input {
                         PipelineData::ExternalStream { exit_code, .. } => exit_code.take(),
