@@ -3,3 +3,5 @@ pub type DeclId = usize;
 pub type BlockId = usize;
 pub type ModuleId = usize;
 pub type OverlayId = usize;
+pub type FileId = usize;
+pub type VirtualPathId = usize;
