@@ -112,7 +112,6 @@ pub struct Signature {
     pub required_positional: Vec<PositionalArg>,
     pub optional_positional: Vec<PositionalArg>,
     pub rest_positional: Option<PositionalArg>,
-    pub vectorizes_over_list: bool,
     pub named: Vec<Flag>,
     pub input_output_types: Vec<(Type, Type)>,
     pub allow_variants_without_examples: bool,
@@ -212,7 +211,6 @@ impl Signature {
             required_positional: vec![],
             optional_positional: vec![],
             rest_positional: None,
-            vectorizes_over_list: false,
             input_output_types: vec![],
             allow_variants_without_examples: false,
             named: vec![],
@@ -464,11 +462,6 @@ impl Signature {
         self
     }
 
-    pub fn vectorizes_over_list(mut self, vectorizes_over_list: bool) -> Signature {
-        self.vectorizes_over_list = vectorizes_over_list;
-        self
-    }
-
     /// Set the input-output type signature variants of the command
     pub fn input_output_types(mut self, input_output_types: Vec<(Type, Type)>) -> Signature {
         self.input_output_types = input_output_types;
